@@ -1,4 +1,4 @@
-/* @(#) $Id: actsync.c,v 1.18 1998/10/13 23:17:48 coneill Exp $ */
+/* @(#) $Id: actsync.c,v 1.18.2.1 1999/03/18 04:17:23 kondou Exp $ */
 /* @(#) Under RCS control in /usr/local/news/src/inn/local/RCS/actsync.c,v */
 /*
  * actsync - sync or merge two active files
@@ -1434,6 +1434,11 @@ get_active(host, hostid, len, grp, errs)
 	/* check for a bad group type */
 	switch (cur->type[0]) {
 	case 'y':
+		/* of COURSE: collabra has incompatible flags. but it	*/
+		/* looks like they can be fixed easily enough.		*/
+		if (cur->type[1] = 'g') {
+			cur->type[1] = '\0';
+		}
 	case 'm':
 	case 'j':
 	case 'n':
