@@ -1,4 +1,4 @@
-/*  $Revision: 1.7 $
+/*  $Revision: 1.9 $
 **
 **  Read batchfiles on standard input and spew out batches.
 */
@@ -349,7 +349,7 @@ main(ac, av)
 	if ((p = strchr(line, ' ')) != NULL) {
 	    *p++ = '\0';
 	    /* Try to be forgiving of bad input. */
-	    BytesInArt = CTYPE(isdigit, *p) ? atol(p) : -1;
+	    BytesInArt = CTYPE(isdigit, (int)*p) ? atol(p) : -1;
 	}
 	else
 	    BytesInArt = -1;
@@ -372,17 +372,19 @@ main(ac, av)
 	    }
 	    BytesInArt = -1;
 	    Token = TRUE;
-	} else if ((artfd = open(p, O_RDONLY)) < 0) {
-	    if (errno != ENOENT)
-		(void)fprintf(stderr, SKIPPING, Host, p, strerror(errno));
-	    if (AltSpool == NULL)
-		continue;
-	    (void)sprintf(buff, "%s/%s", AltSpool, p);
-	    if ((artfd = open(buff, O_RDONLY)) < 0) {
-		if (errno != ENOENT)
-		    (void)fprintf(stderr, SKIPPING,
-			    Host, buff, strerror(errno));
-		continue;
+	} else {
+	    if ((artfd = open(p, O_RDONLY)) < 0) {
+	        if (errno != ENOENT)
+		    (void)fprintf(stderr, SKIPPING, Host, p, strerror(errno));
+	        if (AltSpool == NULL)
+		    continue;
+	        (void)sprintf(buff, "%s/%s", AltSpool, p);
+	        if ((artfd = open(buff, O_RDONLY)) < 0) {
+		    if (errno != ENOENT)
+		        (void)fprintf(stderr, SKIPPING,
+			        Host, buff, strerror(errno));
+		    continue;
+	        }
 	    }
 	    Token = FALSE;
 	}
@@ -549,4 +551,5 @@ main(ac, av)
 	BATCHstatus = BATCHclose(F);
     RequeueAndExit(Cookie, (char *)NULL, 0L);
     /* NOTREACHED */
+    return 0;
 }
