@@ -1,4 +1,4 @@
-/*  $Revision: 1.47 $
+/*  $Revision: 1.51 $
 **
 **  Rebuild the history database.
 **
@@ -83,7 +83,6 @@ static void ARTreadschema(BOOL Overview)
     ARTOVERFIELD                *fp;
     int                         i;
     char                        buff[SMBUF];
-    int				missing = 0;
 
     if (Overview) {
 	/* Open file, count lines. */
@@ -253,13 +252,13 @@ RemoveDBZFiles(char *p)
 /*
 **  Rebuild the DBZ file from the text file.
 */
-STATIC void Rebuild(long size, BOOL IgnoreOld, BOOL Overwrite)
+STATIC void Rebuild(OFFSET_T size, BOOL IgnoreOld, BOOL Overwrite)
 {
     QIOSTATE	        *qp;
     char	        *p, *q;
     char	        *save;
-    long	        count;
-    long		where;
+    OFFSET_T	        count;
+    OFFSET_T		where;
     HASH		key;
     char		temp[SMBUF];
     dbzoptions          opt;
@@ -510,9 +509,13 @@ ReadInMem(char *art, ARTHANDLE *arth, char *Tradspooldir)
     if (!FoundXref) {
 	/* assumes not crossposted */
 	sprintf(path, "%s %s %s\r\n\r\n", XREF, pathhost, art);
-	if ((p = strrchr(path, '/')) != (char *)NULL)
+	if ((p = strrchr(path, '/')) != (char *)NULL) {
 	    *p = ':';
-	else {
+	    for (p = path; *p; p++)
+	      if (*p == '/')
+		*p = '.';
+	    
+	} else {
 	    QIOclose(qp);
 	    return FALSE;
 	}
@@ -1239,7 +1242,7 @@ DoNewsgroup(char *group, FILE *out, BOOL RemoveBad, BOOL Update, TRANS Translate
     /* Read all entries in the directory. */
     while ((ep = readdir(dp)) != NULL) {
 	p = ep->d_name;
-	if (!CTYPE(isdigit, *p) || strspn(p, "0123456789") != strlen(p))
+	if (!CTYPE(isdigit, (int)*p) || strspn(p, "0123456789") != strlen(p))
 	    continue;
 
 	strcpy(q, p);
@@ -1396,8 +1399,7 @@ Usage(void)
 }
 
 
-int
-main(int ac, char *av[])
+int main(int ac, char *av[])
 {
     QIOSTATE		*qp;
     FILE		*out;
@@ -1406,7 +1408,7 @@ main(int ac, char *av[])
     char		*q;
     long		count;
     BUFFER		B;
-    long		size;
+    OFFSET_T		size;
     int			i;
     BOOL		JustRebuild;
     BOOL		DoRebuild;
@@ -1429,7 +1431,6 @@ main(int ac, char *av[])
     char		*tv[2];
     STRING		tmpdir;
     STRING		OverPath;
-    char		*Tflag;
     char		*mode;
     char		*oldtemp;
     ARTHANDLE		*art = (ARTHANDLE *)NULL;
@@ -1460,7 +1461,6 @@ main(int ac, char *av[])
     Translate = NO_TRANS;
     Tradspooldir = innconf->patharticles;
     OldHistory = HISTORY;
-    Tflag = "";
     mode = "w";
     size = 0;
     oldtemp = NULL;
@@ -1526,8 +1526,6 @@ main(int ac, char *av[])
 	    break;
 	case 'T':
 	    tmpdir = optarg;
-	    Tflag = NEW(char, 3 + strlen(optarg) + 1);
-	    (void)sprintf(Tflag, "-T %s", optarg);
 	    break;
 	case 't':
 	    switch(*optarg) {
@@ -1752,10 +1750,10 @@ main(int ac, char *av[])
     /* Make a temporary file, sort the text file into it. */
     (void)sprintf(temp, "%s/histXXXXXX", tmpdir);
     (void)mktemp(temp);
-    i = 50 + strlen(TempTextFile ? TempTextFile : TextFile) + strlen(temp);
+    i = 50 + strlen(TempTextFile ? TempTextFile : TextFile) + strlen(temp) + 3 + strlen(tmpdir);
     p = NEW(char, i);
-    (void)sprintf(p, "exec sort %s -t'%c' +1n -o %s %s",
-	    Tflag, HIS_FIELDSEP, temp, TempTextFile ? TempTextFile : TextFile);
+    (void)sprintf(p, "exec sort -T %s -t'%c' +1n -o %s %s",
+	    tmpdir, HIS_FIELDSEP, temp, TempTextFile ? TempTextFile : TextFile);
 
     i = system(p) >> 8;
     if (i != 0) {
