@@ -1,18 +1,19 @@
-/*  $Revision: 1.22 $
+/*  $Revision: 1.11 $
 **
 **  Send control messages to the InterNetNews daemon.
 */
-#include "configdata.h"
 #include <stdio.h>
+#include <sys/types.h>
+#include "configdata.h"
+#include "clibrary.h"
 #include <ctype.h>
 #include <errno.h>
-#include <sys/types.h>
 #include <sys/stat.h>
 #include "libinn.h"
-#include "clibrary.h"
 #include "inndcomm.h"
 #include "paths.h"
 #include "macros.h"
+#include <syslog.h>  
 
 
 /*
@@ -28,8 +29,10 @@ typedef struct _COMMAND {
 
 
 STATIC COMMAND	Commands[] = {
-    {	"addhist",	"id post exp path...\tAdd history line",
-	4,	SC_ADDHIST,	TRUE	},
+    {	"addhist",	"id arr exp post path...\tAdd history line",
+	5,	SC_ADDHIST,	TRUE	},
+    {	"allow",	"reason...\t\t\tAllow remote connections",
+	1,	SC_ALLOW,	TRUE	},
     {	"begin",	"site\t\t\tStart newly-added site",
 	1,	SC_BEGIN,	FALSE	},
     {	"cancel",	"id\t\t\tCancel message locally",
@@ -40,6 +43,12 @@ STATIC COMMAND	Commands[] = {
 	0,	SC_CHECKFILE,	FALSE	},
     {	"drop",		"site\t\t\tStop feeding site",
 	1,	SC_DROP,	FALSE		},
+    {	"feedinfo",		"site\t\t\tPrint state of feed to site*",
+	1,	SC_FEEDINFO,	FALSE		},
+#if defined(DO_TCL)
+    {	"tcl",			"flag\t\t\tEnable or disable Tcl filtering",
+	1,	SC_FILTER,	FALSE		},
+#endif /* defined(DO_TCL) */
     {	"flush",	"site\t\t\tFlush feed for site*",
 	1,	SC_FLUSH,	FALSE	},
     {	"flushlogs",	"\t\t\tFlush log files",
@@ -48,6 +57,8 @@ STATIC COMMAND	Commands[] = {
 	1,	SC_GO,		TRUE	},
     {	"hangup",	"channel\t\tHangup specified incoming channel",
 	1,	SC_HANGUP,	FALSE	},
+    {	"logmode",		"\t\t\t\tSend server mode to syslog",
+	0,	SC_LOGMODE,	FALSE		},
     {	"mode",		"\t\t\t\tPrint operating mode",
 	0,	SC_MODE,	FALSE		},
     {	"name",		"nnn\t\t\tPrint name of specified channel*",
@@ -58,10 +69,14 @@ STATIC COMMAND	Commands[] = {
 	2,	SC_PARAM,	FALSE	},
     {	"pause",	"reason...\t\tShort-term pause in accepting articles",
 	1,	SC_PAUSE,	TRUE	},
+#if defined(DO_PERL)
+    {	"perl",			"flag\t\t\tEnable or disable Perl filtering",
+	1,	SC_PERL,	FALSE	},
+#endif /* defined(DO_PERL) */
     {	"readers",	"flag text...\t\tEnable or disable newsreading",
 	2,	SC_READERS,	TRUE	},
-    {	"refile",	"path group\t\tRefile an article",
-	2,	SC_REFILE,	FALSE	},
+    {	"reject",	"reason...\t\t\tReject remote connections",
+	1,	SC_REJECT,	TRUE	},
     {	"reload",	"what reason...\t\tRe-read config files*",
 	2,	SC_RELOAD,	TRUE	},
     {	"renumber",	"group\t\tRenumber the active file*",
@@ -74,14 +89,22 @@ STATIC COMMAND	Commands[] = {
 	2,	SC_SEND,	TRUE	},
     {	"shutdown",	"reason...\t\tShut down server",
 	1,	SC_SHUTDOWN,	TRUE	},
+    {	"status",	"interval|off\t\tTurn innd status generation on or off",
+	1,	SC_STATUS,	FALSE	},
     {	"kill",	"signal site\t\tSend signal to site's process",
 	2,	SC_SIGNAL,	FALSE	},
     {	"throttle",	"reason...\t\tStop accepting articles",
 	1,	SC_THROTTLE,	TRUE	},
+    {   "timer",	"interval|off\t\tTurn performance monitoring on or off",
+	1,	SC_TIMER,	FALSE	},
     {	"trace",	"innd|#|nnrpd flag\tTurn tracing on or off",
 	2,	SC_TRACE,	FALSE	},
     {	"xabort",	"text...\t\tAbort the server",
 	1,	SC_XABORT,	TRUE	},
+    { "lowmark",	"filename\t\tReset active file low article marks",
+	1,	SC_LOWMARK,	FALSE	},
+    { "renumberlow",	"filename\t\tReset active file low article marks",
+	1,	SC_LOWMARK,	FALSE	},
     {	"xexec",	"path\t\t\tExec new server",
 	1,	SC_XEXEC,	FALSE	}
 };
@@ -136,7 +159,11 @@ STATIC NORETURN
 Failed(p)
     char	*p;
 {
-    (void)fprintf(stderr, "Can't %s, %s.\n", p, strerror(errno));
+    if (ICCfailure)
+	(void)fprintf(stderr, "Can't %s (%s failure) %s.\n",
+		p, ICCfailure, strerror(errno));
+    else
+	(void)fprintf(stderr, "Can't %s, %s.\n", p, strerror(errno));
     (void)ICCclose();
     exit(1);
 }
@@ -154,16 +181,13 @@ Usage(what)
 }
 
 
-int
-main(ac, av)
-    int			ac;
-    char		*av[];
+int main(int ac, char *av[])
 {
     static char		Y[] = "y";
     static char		EMPTY[] = "";
-    register COMMAND	*cp;
-    register char	*p;
-    register int	i;
+    COMMAND	        *cp;
+    char	        *p;
+    int	                i;
     BOOL		Silent;
     BOOL		NeedHelp;
     char		*reply;
@@ -173,7 +197,11 @@ main(ac, av)
     struct stat		Sb;
     char		buff[SMBUF];
 
+    /* First thing, set up logging and our identity. */
+    openlog("ctlinnd", L_OPENLOG_FLAGS | LOG_PID, LOG_INN_PROG);        
+
     /* Set defaults. */
+    if (ReadInnConf() < 0) exit(1);
     Silent = FALSE;
     NeedHelp = FALSE;
     ICCsettimeout(CTLINND_TIMEOUT);
@@ -254,8 +282,8 @@ main(ac, av)
 	/* Glue any extra words together. */
 	for (length = 0, i = cp->argc - 1; (p = av[i++]) != NULL; )
 	    length += strlen(p) + 1;
-	for (new = p = NEW(char, length + 1), i = cp->argc - 1; av[i]; i++) {
-	    if (i)
+	for (new = p = NEW(char, length), i = cp->argc - 1; av[i]; i++) {
+	    if (i >= cp->argc)
 		*p++ = ' ';
 	    p += strlen(strcpy(p, av[i]));
 	}
@@ -280,7 +308,8 @@ main(ac, av)
     i = ICCcommand(cp->Letter, av, &reply);
     if (i < 0) {
 	i = errno;
-	if (stat(_PATH_SERVERPID, &Sb) < 0)
+	p = cpcatpath(innconf->pathrun, _PATH_SERVERPID);
+	if (stat(p, &Sb) < 0)
 	    (void)fprintf(stderr, "No innd.pid file; did server die?\n");
 	(void)sprintf(buff, "send \"%s\" command", cp->Command);
 	errno = i;
