@@ -1,4 +1,4 @@
-/*  $Revision: 1.4 $
+/*  $Revision: 1.2 $
 **  Produce a seven-bit printable encoding of stdin on stdout.
 **  From @(#)encode.c 1.3 5/15/85, distributed with B2.11 News.
 **
@@ -117,7 +117,7 @@ main(ac, av)
 	    p = b3;
 	}
     }
-    encode(b3, p - b3);
+    encode(b3, (int)(p - b3));
     flushout();
     exit(0);
     /* NOTREACHED */
