@@ -1,4 +1,4 @@
-/*  $Revision: 1.10 $
+/*  $Revision: 1.12 $
 **
 ** Provide a command line interface to the storage manager
 */
@@ -15,7 +15,7 @@
 #include <syslog.h>  
 
 void Usage(void) {
-    fprintf(stderr, "Usage sm [-q] [-r] [-d] [-o] token [token] [token] ...\n");
+    fprintf(stderr, "Usage sm [-q] [-r] [-d] [-o] [-R] token [token] [token] ...\n");
     exit(1);
 }
 
@@ -24,19 +24,21 @@ int main(int argc, char **argv) {
     BOOL                Quiet = FALSE;
     BOOL                Delete = FALSE;
     BOOL                Overview = FALSE;
+    BOOL                Rawformat = FALSE;
     BOOL		val;
     int                 i;
     char                *p;
     QIOSTATE            *qp;
     TOKEN		token;
     int			linelen;
+    ARTHANDLE		*art;
     
     /* First thing, set up logging and our identity. */
     openlog("sm", L_OPENLOG_FLAGS | LOG_PID, LOG_INN_PROG);     
 
     if (ReadInnConf() < 0) { exit(1); }
 
-    while ((c = getopt(argc, argv, "qrdo")) != EOF) {
+    while ((c = getopt(argc, argv, "qrdoR")) != EOF) {
 	switch (c) {
 	case 'q':
 	    Quiet = TRUE;
@@ -48,6 +50,9 @@ int main(int argc, char **argv) {
 	case 'o':
 	    Overview = TRUE;
 	    break;
+	case 'R':
+	    Rawformat = TRUE;
+	    break;
 	default:
 	    Usage();
 	}
@@ -114,6 +119,7 @@ int main(int argc, char **argv) {
 	    if ((p = OVERretrieve(&token, &linelen)) == (char *)NULL) {
 		if (!Quiet)
 		    fprintf(stderr, "Could not retrieve %s\n", argv[i]);
+		continue;
 	    }
 	    if (fwrite(p, linelen, 1, stdout) != 1) {
 		if (!Quiet)
@@ -122,21 +128,41 @@ int main(int argc, char **argv) {
 	    }
 	    printf("\n");
 	} else {
-	    if ((qp = QIOopen(argv[i])) == NULL) {
-		if (!Quiet)
-		    fprintf(stderr, "Could not open %s\n", argv[i]);
-		continue;
+	    if (Rawformat) {
+		if (!IsToken(argv[i])) {
+		    if (!Quiet)
+			fprintf(stderr, "%s is not a storage token\n", argv[i]);
+		    continue;
+		}
+		token = TextToToken(argv[i]);
+		if ((art = SMretrieve(token, RETR_ALL)) == NULL) {
+		    if (!Quiet)
+			fprintf(stderr, "Could not retrieve %s\n", argv[i]);
+		    continue;
+		}
+		if (fwrite(art->data, art->len, 1, stdout) != 1) {
+		    if (!Quiet)
+			fprintf(stderr, "Output failed\n");
+		    exit(1);
+		}
+		SMfreearticle(art);
 	    } else {
-		while ((p = QIOread(qp)) != NULL) {
-		    if (QIOlength(qp) != 0)
-			if (fwrite(p, QIOlength(qp), 1, stdout) != 1) {
-			    if (!Quiet)
-				fprintf(stderr, "Output failed: %s\n", strerror(errno));
-			    exit(1);
-			}
-		    printf("\n");
+		if ((qp = QIOopen(argv[i])) == NULL) {
+		    if (!Quiet)
+			fprintf(stderr, "Could not open %s\n", argv[i]);
+		    continue;
+		} else {
+		    while ((p = QIOread(qp)) != NULL) {
+			if (QIOlength(qp) != 0)
+			    if (fwrite(p, QIOlength(qp), 1, stdout) != 1) {
+				if (!Quiet)
+				    fprintf(stderr, "Output failed: %s\n", strerror(errno));
+				exit(1);
+			    }
+			printf("\n");
+		    }
+		    QIOclose(qp);
 		}
-		QIOclose(qp);
 	    }
 	}
 	  
