@@ -1,4 +1,4 @@
-/*  $Revision: 1.34 $
+/*  $Revision: 1.37 $
 **
 **  Here be configuration data used by various InterNetNews programs.
 **  The numbers refer to sections in the config.dist file.
@@ -94,9 +94,6 @@
     /* Null-terminated set of illegal distribution patterns. */
     /* =()<#define BAD_DISTRIBS	@<BAD_DISTRIBS>@>()= */
 #define BAD_DISTRIBS	"*.*",NULL
-    /* File unknown "to.*" groups into the "to" newsgroup? */
-    /* =()<#define @<MERGE_TO_GROUPS>@_MERGE_TO_GROUPS>()= */
-#define DONT_MERGE_TO_GROUPS
     /* Have innd throttle itself after this many I/O errors. */
     /* =()<#define IO_ERROR_COUNT	@<IO_ERROR_COUNT>@>()= */
 #define IO_ERROR_COUNT	50
@@ -142,9 +139,6 @@
     /* How your DBZ be compiled? Use tagged-hash or splitted tables */
     /* =()<#define @<DBZ_TAGGED_HASH>@_TAGGED_HASH>()= */
 #define DONT_TAGGED_HASH
-    /* Do you have shadow file? */
-    /* =()<#define @<HAVE_SHADOW>@_HAVE_SHADOW @<HAVE_SHADOW>@>()= */
-#define DO_HAVE_SHADOW DO
 
 
     /* Function that returns no value, and a pointer to it. */
@@ -245,7 +239,7 @@ typedef int		BOOL;
 */
 
     /* =()<#define @<PERL_SUPPORT>@_PERL>()= */
-#define DONT_PERL
+#define DO_PERL
 
 
 /*
@@ -253,6 +247,6 @@ typedef int		BOOL;
 */
 
     /* =()<#define @<KEYWORDS>@_KEYWORDS>()= */
-#define DONT_KEYWORDS
+#define DO_KEYWORDS
 
 #endif /* ! defined (__configdata_h__) */
