@@ -1,4 +1,4 @@
-/*  $Revision: 1.41 $
+/*  $Revision: 1.47.2.1 $
 **
 **  Here be declarations of functions in the InterNetNews library.
 */
@@ -104,7 +104,7 @@ struct conf_vars {
 	int linecountfuzz;	/* Check linecount and adjust of out by more */
 	int peertimeout;	/* How long peers can be inactive */
 	int clienttimeout;	/* How long nnrpd can be inactive */
-	int allowreaders;	/* Allow nnrpd when server is paused */
+	int readerswhenstopped;	/* Allow nnrpd when server is paused */
 	int allownewnews;	/* Allow use of the 'NEWNEWS' command */
 	long localmaxartsize;	/* Max article size of local postings */
 	int logartsize;		/* Log article sizes */
@@ -120,6 +120,7 @@ struct conf_vars {
 	int blockbackoff;	/* Multiplier for sleep in EWOULDBLOCK writes */
 	int icdsynccount;	/* How many article-writes between active and history updates */
 	char *bindaddress;	/* Which interface IP to bind to */
+	char *sourceaddress;	/* Source IP for outgoing NNTP connections */
 	int port;		/* Which port INND should listen on */
 	int readertrack;	/* Enable/Disable the reader tracking system */
 	int strippostcc;	/* Strip To:, Cc: and Bcc: lines from posts */
@@ -128,6 +129,7 @@ struct conf_vars {
         int keylimit;		/* max allocated space for keywords. */
         int keyartlimit;        /* Max size of an article for keyword generation */
         int keymaxwords;	/* Max count of interesting workd */
+        int nnrpperlauth;       /* Use perl for nnrpd authentication */
 
 	char *pathnews;	
 	char *pathbin;
@@ -148,6 +150,7 @@ struct conf_vars {
 	int logsitename;	/* log site names? */
 	char *pathhttp;
 	char *nnrpdposthost;
+	int nnrpdpostport;
 	int extendeddbz;
 	int nnrpdoverstats;
 	int storeonxref;	/* Should SMstore() see Xref to detemine class */
@@ -164,6 +167,10 @@ struct conf_vars {
 	long activedupdate;
 	int activedport;
 	int storemsgid;
+	int nicenewnews;	/* If NEWNEWS command is used, set nice */
+	int usecontrolchan;
+	int mergetogroups;
+	int noreader;
 };
 extern struct	conf_vars *innconf;
 extern char	*innconffile;
@@ -193,7 +200,7 @@ extern int	GetTimeInfo(TIMEINFO *Now);
 typedef struct {
     char        hash[16];
 } HASH;
-HASH Hash(const void *value, size_t len);
+HASH Hash(const void *value, const size_t len);
 /* Return the hash of a case mapped message-id */
 HASH HashMessageID(const char *MessageID);
 BOOL HashEmpty(const HASH hash);
