@@ -1,5 +1,5 @@
 /*
- * $Revision: 1.6.2.3 $
+ * $Revision: 1.6.2.4 $
  */
 
 
@@ -13,11 +13,11 @@
 **  Try to avoid changing these.
 */
 #define RELEASE "2"
-#define PATCHLEVEL "2"
-#define DATE "21-Jan-1999"
+#define PATCHLEVEL "2.1"
+#define DATE "25-Aug-1999"
 #define RELEASE_C 2
 #define PATCHLEVEL_C 2
-#define SUB_PATCHLEVEL_C 0
+#define SUB_PATCHLEVEL_C 1
 
 
 /*
