@@ -1,4 +1,4 @@
-/*  $Id: cc.c,v 1.42 1998/06/18 15:45:15 kondou Exp $
+/*  $Id: cc.c,v 1.47.2.6 1999/07/08 21:18:34 kondou Exp $
 **
 **  Routines for the control channel.  Create a Unix-domain datagram socket
 **  that processes on the local server send messages to.  The control
@@ -16,6 +16,7 @@
 #include "clibrary.h"
 #include "innd.h"
 #include "inndcomm.h"
+#include "qio.h"
 #if	defined(HAVE_UNIX_DOMAIN_SOCKETS)
 #include <sys/un.h>
 #endif	
@@ -71,6 +72,7 @@ STATIC STRING	CCperl();
 #endif /* defined(DO_PERL) */
 STATIC STRING	CClowmark();
 
+
 STATIC char		*CCpath = NULL;
 STATIC char		**CCargv;
 STATIC char		CCnosite[] = "1 No such site";
@@ -81,6 +83,7 @@ STATIC char		CCnoreason[] = "1 Empty reason";
 STATIC char		CCbigreason[] = "1 Reason too long";
 STATIC char		CCnotrunning[] = "1 Must be running";
 STATIC BUFFER		CCreply;
+STATIC BUFFER		CCperlbuff;
 STATIC CHANNEL		*CCchan;
 STATIC int		CCwriter;
 STATIC CCDISPATCH	CCcommands[] = {
@@ -240,24 +243,19 @@ CCaddhist(av)
     HASH                hash;
     int			i;
     TOKEN		token;
-    OFFSET_T		offset;
-    unsigned char	index;
-    unsigned short	len;
 
     /* Check to see if we were passed a hash first. */
     i = strlen(av[0]);
     if (av[0][0]=='[' && av[0][i-1] == ']') {
 	if (i != ((sizeof(HASH) * 2) + 2))
 	    return "1 Bad Hash";
-	index = OVER_NONE;
-	offset = 0;
-	len = 0;
-	OVERsetoffset(&token, &offset, &index, &len);
 	if (av[4] != NULL && *av[4] != '\0') {
 	    if (!IsToken(av[4]))
 		return "1 Bad Token";
 	    else
 		token = TextToToken(av[4]);
+	} else {
+	    OVERmaketoken(&token, (OFFSET_T)0, OVER_NONE, 0);
 	}
         hash = TextToHash(&av[0][1]);
 	/* Put something bogus in here.  This should never be referred
@@ -635,6 +633,12 @@ typedef enum { false = 0, true = 1 } bool;
 #include <perl.h>
 #include <XSUB.h>
 
+/* Perl 5.004 didn't define ERRSV and PL_na was called na. */
+#ifndef ERRSV
+# define ERRSV GvSV(errgv)
+# define PL_na na
+#endif
+
 extern CV *perl_filter_cv ;
 
 STATIC STRING
@@ -746,7 +750,7 @@ CCgo(av)
     Mode = OMrunning;
     ThrottledbyIOError = FALSE;
 
-    if (NNRPReason && innconf->allowreaders) {
+    if (NNRPReason && !innconf->readerswhenstopped) {
 	av[0] = YES;
 	av[1] = p;
 	(void)CCreaders(av);
@@ -757,11 +761,11 @@ CCgo(av)
     if (innconf->storageapi) {
 	int fdcountold = Overfdcount;
 	if (!OVERinit()) {
-	    syslog(L_FATAL, "%s cant initialize the unified overview");
+	    syslog(L_FATAL, "%s cant initialize the unified overview", LogName);
 	    exit(1);
 	}
 	if ((Overfdcount = OVERgetnum()) < 0) {
-            syslog(L_FATAL, "%s cant get config for the unified overview");
+            syslog(L_FATAL, "%s cant get config for the unified overview", LogName);
             exit(1);
 	}
 	if (fdcountold != Overfdcount) {
@@ -896,7 +900,7 @@ CCmode(av)
     /* Newsreaders. */
     *p++ = '\n';
     p += strlen(strcpy(p, "Readers "));
-    if (innconf->allowreaders)
+    if (innconf->readerswhenstopped)
 	p += strlen(strcpy(p, "follow "));
     else
 	p += strlen(strcpy(p, "separate "));
@@ -1135,7 +1139,7 @@ CCparam(av)
 	syslog(L_NOTICE, "%s changed -l %ld", LogName, innconf->maxartsize);
 	break;
     case 'n':
-	if (!CCparsebool('n', &innconf->allowreaders, *p))
+	if (!CCparsebool('n', &innconf->readerswhenstopped, *p))
 	    return BADVAL;
 	break;
     case 'o':
@@ -1208,7 +1212,7 @@ CCblock(NewMode, reason)
     if (ModeReason)
 	DISPOSE(ModeReason);
     ModeReason = COPY(reason);
-    if (NNRPReason == NULL && innconf->allowreaders) {
+    if (NNRPReason == NULL && !innconf->readerswhenstopped) {
 	av[0] = NO;
 	av[1] = ModeReason;
 	(void)CCreaders(av);
@@ -1283,6 +1287,7 @@ CCxexec(av)
 {
     char	*inndstart;
     char	*p;
+    int		i;
 
     if (CCargv == NULL)
 	return "1 no argv!";
@@ -1297,6 +1302,11 @@ CCxexec(av)
 
     JustCleanup();
     syslog(L_NOTICE, "%s execv %s", LogName, CCargv[0]);
+
+    /* Close all fds to protect possible fd leaking accross successive innds. */
+    for (i=3; i<30; i++)
+        (void)close(i);
+
     (void)execv(CCargv[0], CCargv);
     syslog(L_FATAL, "%s cant execv %s %m", LogName, CCargv[0]);
     _exit(1);
@@ -1344,11 +1354,11 @@ CCreload(av)
 	if (innconf->storageapi) {  
 	    int fdcountold = Overfdcount;
 	    if (!OVERinit()) {
-		syslog(L_FATAL, "%s cant initialize the unified overview");
+		syslog(L_FATAL, "%s cant initialize the unified overview", LogName);
 		exit(1);
 	    } 
 	    if ((Overfdcount = OVERgetnum()) < 0) {
-		syslog(L_FATAL, "%s cant get config for the unified overview");
+		syslog(L_FATAL, "%s cant get config for the unified overview", LogName);
 		exit(1);
 	    }
 	    if (fdcountold != Overfdcount) {
@@ -1388,11 +1398,11 @@ CCreload(av)
 	    int fdcountold = Overfdcount;
 	    OVERshutdown();
 	    if (!OVERinit()) {
-		syslog(L_FATAL, "%s cant initialize the unified overview");
+		syslog(L_FATAL, "%s cant initialize the unified overview", LogName);
 		exit(1);
 	    } 
 	    if ((Overfdcount = OVERgetnum()) < 0) {
-		syslog(L_FATAL, "%s cant get config for the unified overview");
+		syslog(L_FATAL, "%s cant get config for the unified overview", LogName);
 		exit(1);
 	    }
 	    if (fdcountold != Overfdcount) {
@@ -2031,7 +2041,301 @@ CCresetup(s)
     CCsetup();
 }
 
-# include "qio.h"
+/*
+ * The beginnings of a perl interface to the INN command set.
+ * I chose to put it in this file to avoid having to rewrite any code,
+ * and to avoid having to change the visibility of any of the functions
+ * in this module.
+ * -- Ed Mooring (mooring@acm.org) May 14, 1998
+ */
+
+#if defined(DO_PERL)
+
+#include "EXTERN.h"
+#include "perl.h"
+#include "XSUB.h"
+
+
+XS(XS_INN_havehist)
+{
+    dXSARGS;
+    char*	msgid;
+
+    if (items != 1)
+        croak("Usage: INN::havehist(msgid)");
+
+    msgid = (char *)SvPV(ST(0),na);
+    if (HIShavearticle(HashMessageID(msgid)))
+	XSRETURN_YES;
+    else
+	XSRETURN_NO;
+}
+
+XS(XS_INN_cancel)
+{
+    dXSARGS;
+    char*	msgid;
+    char*	parambuf[2];
+
+    if (items != 1)
+        croak("Usage: INN::cancel(msgid)");
+
+    msgid = (char *)SvPV(ST(0),na);
+    parambuf[0]=msgid;
+    parambuf[1]= 0;
+    /* CCcancel returns NULL on success, hence reversed return codes */
+    if (CCcancel(parambuf))
+	XSRETURN_NO;
+    else
+	XSRETURN_YES;
+}
+
+XS(XS_INN_addhist)
+{
+    dXSARGS;
+    char*	msgid;
+    char*	arrivaltime;
+    char*	articletime;
+    char*	expiretime;
+    char*	articlepaths = "";
+    char	tbuff[12];
+    char*	parambuf[6];
+
+    if (items < 1 || items > 5)
+	croak("Usage INN::addhist(msgid,[arrivaltime,articletime,expiretime,paths])");
+
+
+    /* we will always have a message id */
+    msgid = (char *)SvPV(ST(0),na);
+
+    /* set up sensible defaults for the time values */
+    sprintf(tbuff, "%d",time((long *)0));
+    arrivaltime = articletime = expiretime = tbuff;
+
+    switch (items) {
+    case 2:
+	arrivaltime = (char *)SvPV(ST(1),na);
+	articletime = expiretime = arrivaltime;
+	break;
+    case 3: 
+	arrivaltime = (char *)SvPV(ST(1),na);
+	articletime = (char *)SvPV(ST(2),na);
+	expiretime = arrivaltime;
+	break;
+    case 4:
+	arrivaltime = (char *)SvPV(ST(1),na);
+	articletime = (char *)SvPV(ST(2),na);
+	expiretime =  (char *)SvPV(ST(3),na);
+	break;
+    case 5:
+	arrivaltime = (char *)SvPV(ST(1),na);
+	articletime = (char *)SvPV(ST(2),na);
+	expiretime =  (char *)SvPV(ST(3),na);
+	articlepaths =  (char *)SvPV(ST(4),na);
+	break;
+    }
+    parambuf[0] = msgid;
+    parambuf[1] = arrivaltime;
+    parambuf[2] = articletime;
+    parambuf[3] = expiretime;
+    parambuf[4] = articlepaths;
+    parambuf[5] = 0;
+
+    /* CCaddhist returns NULL on success, hence reversed return codes */
+    if (CCaddhist(parambuf))
+	XSRETURN_NO;
+    else
+	XSRETURN_YES;
+}
+
+XS(XS_INN_newsgroup)
+{
+    dXSARGS;
+    char*	newsgroup;
+    NEWSGROUP*  ngp;
+    char*	end;
+    char*	rest;
+    int		size;
+
+    if (items != 1)
+        croak("Usage: INN::newsgroup(msgid)");
+    newsgroup = (char *)SvPV(ST(0),na);
+
+    if ((ngp = NGfind(newsgroup)) == NULL)
+	XSRETURN_UNDEF;
+    else {
+	/* ngp->Rest is newline-terminated; find the end. */
+	end = strchr(ngp->Rest, '\n');
+	if (end == NULL) {
+	    size = strlen(ngp->Rest);
+	} else {
+	    size = end - ngp->Rest;
+	}
+
+	if (CCperlbuff.Data == NULL) {
+	    CCperlbuff.Size = SITE_BUFFER_SIZE;
+	    CCperlbuff.Data = NEW(char, CCperlbuff.Size);
+	}
+
+	/* SITE_BUFFER_SIZE should be *huge* for this, but be paranoid. */
+	if (size > SITE_BUFFER_SIZE + 1)
+	    size = SITE_BUFFER_SIZE;
+
+	strncpy(CCperlbuff.Data, ngp->Rest, size);
+	CCperlbuff.Data[size] = '\0';
+	XSRETURN_PV(CCperlbuff.Data);
+    }
+}
+
+XS(XS_INN_filesfor)
+{
+    dXSARGS;
+    char*	msgid;
+    char*	files;
+
+    if (items != 1)
+        croak("Usage: INN::filesfor(msgid)");
+
+    msgid = (char *)SvPV(ST(0),na);
+    files = HISfilesfor(HashMessageID(msgid));
+    if (files) {
+        XSRETURN_PV(files);
+    }
+    else {
+        XSRETURN_UNDEF;
+    }
+}
+
+XS(XS_INN_head)
+{
+    dXSARGS;
+    char*		msgid;
+    char*		p;
+    char*		q;
+    char*		bufptr;
+    QIOSTATE*		qp;
+
+    if (items != 1)
+        croak("Usage: INN::head(msgid)");
+
+    msgid = (char *)SvPV(ST(0),PL_na);
+
+    /* Get the article filenames; open the first file */
+    if ((q = HISfilesfor(HashMessageID(msgid))) == NULL) {
+	XSRETURN_UNDEF;
+    }
+    if ((p = strchr(q, ' ')))
+	*p = '\0';
+
+    if ((qp = QIOopen(q)) == NULL) {
+	XSRETURN_UNDEF;
+    }
+
+    if (CCperlbuff.Data == NULL) {
+	CCperlbuff.Size = SITE_BUFFER_SIZE;
+	CCperlbuff.Data = NEW(char, CCperlbuff.Size);
+    }
+                                        
+    strcpy(CCperlbuff.Data, "");
+
+    for (p = QIOread(qp); (p != NULL) && (*p != '\0'); p = QIOread(qp)) {
+	if (CCperlbuff.Size < (qp->Count + 3)) {
+	    CCperlbuff.Size += SITE_BUFFER_SIZE;
+	    RENEW(CCperlbuff.Data, char, CCperlbuff.Size);
+        }
+	strncat(CCperlbuff.Data, p, QIOlength(qp));
+	strncat(CCperlbuff.Data, "\n", 1);
+    }
+    QIOclose(qp);
+    XSRETURN_PV(CCperlbuff.Data);
+}
+
+XS(XS_INN_article)
+{
+    dXSARGS;
+    char*		msgid;
+    char*		p;
+    char*		q;
+    char*		bufptr;
+    QIOSTATE*		qp;
+
+    if (items != 1)
+	croak("Usage: INN::article(msgid)");
+
+    msgid = (char *)SvPV(ST(0),PL_na);
+
+    /* Get the article filenames; open the first file */
+    if ((q = HISfilesfor(HashMessageID(msgid))) == NULL) {
+	XSRETURN_UNDEF;
+    }
+    if ((p = strchr(q, ' ')))
+	*p = '\0';
+
+    if ((qp = QIOopen(q)) == NULL) {
+	XSRETURN_UNDEF;
+    }
+
+    if (CCperlbuff.Data == NULL) {
+	CCperlbuff.Size = SITE_BUFFER_SIZE;
+	CCperlbuff.Data = NEW(char, CCperlbuff.Size);
+    }
+                                        
+    strcpy(CCperlbuff.Data, "");
+
+    for (p = QIOread(qp); (p != NULL); p = QIOread(qp)) {
+	if (CCperlbuff.Size < (qp->Count + 3)) {
+	    CCperlbuff.Size += SITE_BUFFER_SIZE;
+	    RENEW(CCperlbuff.Data, char, CCperlbuff.Size);
+	}
+	strncat(CCperlbuff.Data, p, QIOlength(qp));
+	strcat(CCperlbuff.Data, "\n");
+    }
+    QIOclose(qp);
+    XSRETURN_PV(CCperlbuff.Data);
+}
+
+XS(XS_INN_syslog)
+{
+    dXSARGS;
+    char*	loglevel;
+    char*	logmsg;
+    int		priority;
+
+    if (items != 2)
+        croak("Usage: INN::syslog(level, message)");
+
+    loglevel = (char *)SvPV(ST(0),PL_na);
+    logmsg = (char *)SvPV(ST(1),PL_na);
+
+    switch (*loglevel) {
+	default:		priority = LOG_NOTICE ;
+	case 'a': case 'A':	priority = LOG_ALERT ;		break;
+	case 'c': case 'C':	priority = LOG_CRIT ;		break;
+	case 'e': case 'E':	priority = LOG_ERR ;		break;
+	case 'w': case 'W':	priority = LOG_WARNING ;	break;
+	case 'n': case 'N':	priority = LOG_NOTICE ;		break;
+	case 'i': case 'I':	priority = LOG_INFO ;		break;
+	case 'd': case 'D':	priority = LOG_DEBUG ;		break;
+    }
+    syslog(priority, "filter: %s", logmsg);
+    XSRETURN_UNDEF;
+}
+
+
+void
+PERLinndAPIinit()
+{
+    newXS("INN::havehist", XS_INN_havehist, "cc.c");
+    newXS("INN::cancel", XS_INN_cancel, "cc.c");
+    newXS("INN::addhist", XS_INN_addhist, "cc.c");
+    newXS("INN::newsgroup", XS_INN_newsgroup, "cc.c");
+    newXS("INN::filesfor", XS_INN_filesfor, "cc.c");
+    newXS("INN::head", XS_INN_head, "cc.c");
+    newXS("INN::article", XS_INN_article, "cc.c");
+    newXS("INN::syslog", XS_INN_syslog, "cc.c");
+}
+#endif
+
 /*
  * Read a file containing lines of the form "newsgroup lowmark",
  * and reset the low article number for the specified groups.
