@@ -1,4 +1,4 @@
-/*  $Revision: 1.41 $
+/*  $Revision: 1.44.2.1 $
 **
 **  Many of the data types used here have abbreviations, such as CT
 **  for CHANNELTYPE.  Here are a list of the conventions and meanings:
@@ -136,10 +136,10 @@ typedef enum _CHANNELSTATE {
 typedef struct _CHANNEL {
     CHANNELTYPE		Type;
     CHANNELSTATE	State;
+    int			fd;
     BOOL		Skip;
     BOOL		Streaming;
     BOOL		NoResendId;
-    int			fd;
     u_long		Duplicate;
     u_long		Unwanted_s;
     u_long		Unwanted_f;
@@ -212,7 +212,7 @@ typedef struct _NEWSGROUP {
     int			Lastwidth;
     int			PostCount;	/* Have we already put it here?	*/
     char		*LastString;
-    char		*Rest;
+    char		*Rest;		/* Flags, NOT NULL TERMINATED */
     SITEIDX		nSites;
     int			*Sites;
     SITEIDX		nPoison;
@@ -485,6 +485,7 @@ extern void		ARTsetup(void);
 extern void		BUFFset(BUFFER *bp, const char *p, const int length);
 extern void		BUFFswap(BUFFER *b1, BUFFER *b2);
 extern void             BUFFappend(BUFFER *bp, const char *p, const int len);
+extern void		BUFFtrimcr(BUFFER *bp);
 
 extern BOOL		CHANsleeping(CHANNEL *cp);
 extern CHANNEL		*CHANcreate(int fd, CHANNELTYPE Type, CHANNELSTATE STate, FUNCPTR Reader, FUNCPTR WriteDone);
@@ -515,7 +516,7 @@ extern STRING		CCcancel();
 extern STRING		CCcheckfile();
 
 extern BOOL		HIShavearticle(const HASH MessageID);
-extern BOOL		HISwrite(const ARTDATA *Data, HASH hash, char *paths, TOKEN *token);
+extern BOOL		HISwrite(const ARTDATA *Data, const HASH hash, char *paths, TOKEN *token);
 extern BOOL             HISremember(const HASH MessageID);
 extern char		*HISfilesfor(const HASH MessageID);
 extern void		HISclose(void);
