@@ -1,7 +1,8 @@
-/*  $Id: inndstart.c,v 1.14 1998/06/03 00:24:51 kondou Exp $
+/*  $Id: inndstart.c,v 1.16.2.2 1999/05/31 03:30:41 kondou Exp $
 **
 **  Open the privileged port, then exec innd.
 */
+#include <pwd.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/types.h>
@@ -58,6 +59,7 @@ int main(int ac, char *av[])
     struct sockaddr_in	server;
     register int	i;
     register int	j;
+    register int	sock;
 #if	defined(SO_REUSEADDR)
     int			on;
 #endif	/* defined(SO_REUSEADDR) */
@@ -68,6 +70,7 @@ int main(int ac, char *av[])
     STRING		env[8];
     struct stat		Sb;
     char		*inndpath;
+    struct passwd	*pwd;
 
     (void)openlog("inndstart", L_OPENLOG_FLAGS, LOG_INN_PROG);
 
@@ -78,6 +81,21 @@ int main(int ac, char *av[])
 	syslog(L_FATAL, "inndstart cant stat %s %m", innconf->pathrun);
 	exit(1);
     }
+    if (Sb.st_uid == 0) {
+	syslog(L_FATAL, "inndstart %s must not be owned by root", innconf->pathrun);
+	exit(1);
+    }
+    pwd = getpwnam(NEWSUSER);
+    if (pwd == (struct passwd *)NULL) {
+	syslog(L_FATAL, "inndstart getpwnam(%s): %s", NEWSUSER, strerror(errno));
+	exit(1);
+    } else if (pwd->pw_gid != Sb.st_gid) {
+	syslog(L_FATAL, "inndstart %s must have group %s", innconf->pathrun, NEWSGRP);
+	exit(1);
+    } else if (pwd->pw_uid != Sb.st_uid) {
+	syslog(L_FATAL, "inndstart %s must be owned by %s", innconf->pathrun, NEWSUSER);
+	exit(1);
+    }
     NewsUID = Sb.st_uid;
     NewsGID = Sb.st_gid;
 
@@ -88,11 +106,31 @@ int main(int ac, char *av[])
     SetDescriptorLimit(NOFILE_LIMIT);
 #endif	/* NOFILE_LIMIT > 0 */
 
+	/* Start actived if required */
+    if (innconf->activedenable && (fork() == 0)) {
+	/* Set our user and group id. */
+	(void)setgid(NewsGID);
+	if (getgid() != NewsGID)
+	    syslog(L_ERROR, "inndstart cant setgid to %d %m", NewsGID);
+	(void)setuid(NewsUID);
+	if (getuid() != NewsUID)
+	    syslog(L_ERROR, "inndstart cant setuid to %d %m", NewsUID);
+	argv = NEW(STRING, 3);
+	argv[0] = cpcatpath(innconf->pathbin, "actived");
+	argv[1] = NULL;
+	env[0] = NULL;
+	(void)execve(argv[0], (CSTRING *)argv, (CSTRING *)env);
+	syslog(L_FATAL, "inndstart cant exec %s %m", argv[0]);
+	_exit(0);
+	/* NOTREACHED */
+    }
+
     /* Create a socket and name it. */
     if ((i = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
 	syslog(L_FATAL, "inndstart cant socket %m");
 	exit(1);
     }
+    sock = i;
 #if	defined(SO_REUSEADDR)
     on = 1;
     if (setsockopt(i, SOL_SOCKET, SO_REUSEADDR, (caddr_t)&on, sizeof on) < 0)
