@@ -4,7 +4,7 @@
  * Start Date:  Wed Nov 29 23:08:24 1995
  * Project:     INN (innfeed)
  * File:        endpoint.c
- * RCSId:       $Id: endpoint.c,v 1.13 1998/06/03 07:23:03 kondou Exp $
+ * RCSId:       $Id: endpoint.c,v 1.14 1998/07/11 03:47:57 kondou Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -38,7 +38,7 @@
  */
 
 #if ! defined (lint)
-static char rcsid [] = "$Id: endpoint.c,v 1.13 1998/06/03 07:23:03 kondou Exp $" ;
+static char rcsid [] = "$Id: endpoint.c,v 1.14 1998/07/11 03:47:57 kondou Exp $" ;
 static void use_rcsid (const char *rId) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rId) ;
 } 
@@ -708,7 +708,7 @@ void Run (void)
         {
           IoStatus rval ;
           int readyCount = sval ;
-          int endpointsServiced = 0 ;
+          int endpointsServiced = 1 ;
           
           handleSignals() ;
           
@@ -726,7 +726,7 @@ void Run (void)
                      loop we check to see if the mainEndPoint fd is ready to
                      read or write. If so we process it and do the current
                      endpoint next time around. */
-                  if (((endpointsServiced % SELECT_RATIO) == 0) &&
+                  if (((endpointsServiced % (SELECT_RATIO + 1)) == 0) &&
                       ep != mainEndPoint && mainEndPoint != NULL &&
                       !mainEpIsReg)
                     {
@@ -735,6 +735,8 @@ void Run (void)
                       int checkRead = FD_ISSET (mainEndPoint->myFd,&rdSet) ;
                       int checkWrite = FD_ISSET (mainEndPoint->myFd,&wrSet) ;
 
+                      endpointsServiced++;
+
                       if (checkRead || checkWrite) 
                         {
                           fd = mainEndPoint->myFd ;
