@@ -1,18 +1,18 @@
-/*  $Revision: 1.8 $
+/*  $Revision: 1.6 $
 **
 */
 #include <stdio.h>
-#include <errno.h>
 #include <sys/types.h>
 #include "configdata.h"
-#include "paths.h"
 #include "clibrary.h"
+#include <errno.h>
+#include "paths.h"
 #include "libinn.h"
 #include "nntp.h"
 #include "macros.h"
 
 
-STATIC char	CApathname[sizeof _PATH_TEMPACTIVE];
+STATIC char	CApathname[256];
 STATIC FILE	*CAfp;
 
 
@@ -20,14 +20,11 @@ STATIC FILE	*CAfp;
 **  Get a copy of the active file for a client host to use, locally or
 **  remotely.
 */
-FILE *
-CAopen(FromServer, ToServer)
-    FILE	*FromServer;
-    FILE	*ToServer;
+FILE *CAopen(FILE *FromServer, FILE *ToServer)
 {
     /* Use a local (or NFS-mounted) copy if available.  Make sure we don't
      * try to delete it when we close it. */
-    if ((CAfp = fopen(_PATH_CLIENTACTIVE, "r")) != NULL) {
+    if ((CAfp = fopen(cpcatpath(innconf->pathetc, _PATH_CLIENTACTIVE), "r")) != NULL) {
 	CApathname[0] = '\0';
 	return CAfp;
     }
@@ -40,18 +37,14 @@ CAopen(FromServer, ToServer)
 /*
 **  Internal library routine.
 */
-FILE *
-CA_listopen(pathname, FromServer, ToServer, request)
-    char	*pathname;
-    FILE	*FromServer;
-    FILE	*ToServer;
-    char	*request;
+FILE *CA_listopen(char *pathname, FILE *FromServer, FILE *ToServer, char *request)
 {
     char	buff[BUFSIZ];
     char	*p;
     int		oerrno;
     FILE	*F;
 
+    (void)unlink(pathname);
     if ((F = fopen(pathname, "w")) == NULL)
 	return NULL;
 
@@ -66,13 +59,14 @@ CA_listopen(pathname, FromServer, ToServer, request)
     if (fgets(buff, sizeof buff, FromServer) == NULL
      || !EQn(buff, NNTP_LIST_FOLLOWS, STRLEN(NNTP_LIST_FOLLOWS))) {
 	oerrno = errno;
-	CAclose();
+	/* Only call CAclose() if opened through CAopen() */
+	if (strcmp(CApathname, pathname) == 0) CAclose();
 	errno = oerrno;
 	return NULL;
     }
 
     /* Slurp up the rest of the response. */
-    while (fgets(buff, sizeof buff, FromServer)) {
+    while (fgets(buff, sizeof buff, FromServer) != NULL) {
 	if ((p = strchr(buff, '\r')) != NULL)
 	    *p = '\0';
 	if ((p = strchr(buff, '\n')) != NULL)
@@ -98,17 +92,13 @@ CA_listopen(pathname, FromServer, ToServer, request)
 **  Use the NNTP list command to get a file from a server.  Default is
 **  the active file, otherwise ask for whatever is in the request param.
 */
-FILE *
-CAlistopen(FromServer, ToServer, request)
-    FILE	*FromServer;
-    FILE	*ToServer;
-    char	*request;
+FILE *CAlistopen(FILE *FromServer, FILE *ToServer, char *request)
 {
     /* Gotta talk to the server -- see if we can. */
     if (FromServer == NULL || ToServer == NULL)
 	return NULL;
 
-    (void)strcpy(CApathname, _PATH_TEMPACTIVE);
+    (void)sprintf(CApathname, "%.220s/%s", innconf->pathtmp, _PATH_TEMPACTIVE);
     (void)mktemp(CApathname);
     return CAfp = CA_listopen(CApathname, FromServer, ToServer, request);
 }
@@ -118,8 +108,7 @@ CAlistopen(FromServer, ToServer, request)
 /*
 **  Close the file opened by CAopen or CAlistopen.
 */
-void
-CAclose()
+void CAclose(void)
 {
     if (CAfp) {
 	(void)fclose(CAfp);
