@@ -4,21 +4,21 @@
 #include <stdio.h>
 #include <sys/types.h>
 #include "configdata.h"
+#include "clibrary.h"
 #if	defined(DO_NEED_TIME)
 #include <time.h>
 #endif	/* defined(DO_NEED_TIME) */
 #include <sys/time.h>
-#include "clibrary.h"
 #include "libinn.h"
 
 
 /* Scale time back a bit, for shorter Message-ID's. */
 #define OFFSET	673416000L
 
-char *
-GenerateMessageID()
+char *GenerateMessageID(void)
 {
     static char		buff[SMBUF];
+    static int		count;
     char		*p;
     char		sec32[10];
     char		pid32[10];
@@ -30,6 +30,6 @@ GenerateMessageID()
     Radix32((unsigned long)getpid(), pid32);
     if ((p = GetFQDN()) == NULL)
 	return NULL;
-    (void)sprintf(buff, "<%sINN%s@%s>", sec32, pid32, p);
+    (void)sprintf(buff, "<%s$%s$%d@%s>", sec32, pid32, ++count, p);
     return buff;
 }
