@@ -3,13 +3,13 @@
  * Author:      Christophe Wolfhugel <wolf@pasteur.fr>
  *		(although he wouldn't recognise it anymore so don't blame him)
  * File:        perl.c
- * RCSId:       $Id: perl.c,v 1.6 1998/05/21 03:00:20 scrappy Exp $
+ * RCSId:       $Id: perl.c,v 1.7.2.1 1999/06/25 03:16:00 kondou Exp $
  * Description: Perl hooks for libinn.a
  * 
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: perl.c,v 1.6 1998/05/21 03:00:20 scrappy Exp $" ;
+static const char *rcsid = "$Id: perl.c,v 1.7.2.1 1999/06/25 03:16:00 kondou Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -18,11 +18,12 @@ static void use_rcsid (const char *rid) {   /* Never called */
 
 #include <stdio.h>
 #include <sys/types.h>
+#include <syslog.h> 
+#include <fcntl.h>
 #include "configdata.h"
 #include "clibrary.h"
-#include <syslog.h> 
-#include "fcntl.h"
-
+#include "libinn.h"
+#include "macros.h"
 
 #if defined(DO_PERL)
 
@@ -34,7 +35,11 @@ typedef enum { false = 0, true = 1 } bool;
 #include <perl.h>
 #include <XSUB.h>
 
-#include "macros.h"
+/* Perl 5.004 didn't define ERRSV and PL_na was called na. */
+#ifndef ERRSV
+# define ERRSV GvSV(errgv)
+# define PL_na na
+#endif
 
 extern void xs_init    _((void));
 extern void boot_DynaLoader _((CV* cv));
@@ -67,10 +72,10 @@ PerlFilter(value)
     if (PerlFilterActive && !value) {
         if (perl_get_cv("filter_end", FALSE) != NULL) {
             perl_call_argv("filter_end", G_EVAL|G_DISCARD|G_NOARGS, NULL);
-            if (SvTRUE(GvSV(errgv)))     /* check $@ */ {
+            if (SvTRUE(ERRSV))     /* check $@ */ {
                 syslog (L_ERROR,"%s perl function filter_end died: %s",
-                        LogName, SvPV(GvSV(errgv), na)) ;
-                POPs ;
+                        LogName, SvPV(ERRSV, PL_na)) ;
+                (void)POPs ;
             }
         } else {
             PerlFilterActive = value ;
@@ -112,8 +117,7 @@ PerlParse ()
 ** function name that must be defined after the file file is loaded for
 ** filtering to be turned on to start with.
 */
-int
-PERLsetup (startupfile, filterfile, function)
+void PERLsetup (startupfile, filterfile, function)
     char *startupfile, *filterfile, *function;
 {
     if (PerlCode == NULL) {
@@ -139,9 +143,9 @@ PERLsetup (startupfile, filterfile, function)
         
         SPAGAIN ;
         
-        if (SvTRUE(GvSV(errgv)))     /* check $@ */ {
+        if (SvTRUE(ERRSV))     /* check $@ */ {
             syslog (L_ERROR,"%s perl loading %s failed: %s",
-                    LogName, startupfile, SvPV(GvSV(errgv), na)) ;
+                    LogName, startupfile, SvPV(ERRSV, PL_na)) ;
             PerlFilter (FALSE) ;
     
         } else {
@@ -176,10 +180,10 @@ PERLreadfilter(filterfile, function)
     
     if (perl_get_cv("filter_before_reload", FALSE) != NULL)    {
         perl_call_argv("filter_before_reload",G_EVAL|G_DISCARD|G_NOARGS,NULL);
-        if (SvTRUE(GvSV(errgv)))     /* check $@ */ {
+        if (SvTRUE(ERRSV))     /* check $@ */ {
             syslog (L_ERROR,"%s perl function filter_before_reload died: %s",
-                    LogName, SvPV(GvSV(errgv), na)) ;
-            POPs ;
+                    LogName, SvPV(ERRSV, PL_na)) ;
+            (void)POPs ;
             PerlFilter (FALSE) ;
         }
     }
@@ -188,9 +192,9 @@ PERLreadfilter(filterfile, function)
     perl_call_argv ("_load_", 0, argv) ;
     PerlUnSilence();
 
-    if (SvTRUE(GvSV(errgv)))     /* check $@ */ {
+    if (SvTRUE(ERRSV))     /* check $@ */ {
         syslog (L_ERROR,"%s perl loading %s failed: %s",
-                LogName, filterfile, SvPV(GvSV(errgv), na)) ;
+                LogName, filterfile, SvPV(ERRSV, PL_na)) ;
         PerlFilter (FALSE) ;
         
         /* If the reload failed we don't want the old definition hanging
@@ -199,9 +203,9 @@ PERLreadfilter(filterfile, function)
         sprintf (argv[0],"undef &%s",function) ;
         perl_call_argv ("_eval_",0,argv) ;
 
-        if (SvTRUE(GvSV(errgv)))     /* check $@ */ {
+        if (SvTRUE(ERRSV))     /* check $@ */ {
             syslog (L_ERROR,"%s perl undef &%s failed: %s",
-                    LogName, function, SvPV(GvSV(errgv), na)) ;
+                    LogName, function, SvPV(ERRSV, PL_na)) ;
         }
         DISPOSE (argv[0]) ;
     } else if ((perl_filter_cv = perl_get_cv(function, FALSE)) == NULL) {
@@ -210,10 +214,10 @@ PERLreadfilter(filterfile, function)
     
     if (perl_get_cv("filter_after_reload", FALSE) != NULL) {
         perl_call_argv("filter_after_reload", G_EVAL|G_DISCARD|G_NOARGS, NULL);
-        if (SvTRUE(GvSV(errgv)))     /* check $@ */ {
+        if (SvTRUE(ERRSV))     /* check $@ */ {
             syslog (L_ERROR,"%s perl function filter_after_reload died: %s",
-                    LogName, SvPV(GvSV(errgv), na)) ;
-            POPs ;
+                    LogName, SvPV(ERRSV, PL_na)) ;
+            (void)POPs ;
             PerlFilter (FALSE) ;
         }
     }
