@@ -1,4 +1,4 @@
-/*  $Revision: 1.7 $
+/*  $Revision: 1.2 $
 **
 */
 #include <stdio.h>
@@ -13,13 +13,14 @@
 /*
 **  Allocate some memory or call the memory failure handler.
 */
-ALIGNPTR
-xmalloc(i)
-    unsigned int	i;
+ALIGNPTR xmalloc(unsigned int i)
 {
     POINTER		new;
 
     while ((new = malloc(i)) == NULL)
 	(*xmemfailure)("malloc", i);
+#if 0
+    memset (new,0,i) ;
+#endif
     return CAST(ALIGNPTR, new);
 }
