@@ -1,4 +1,4 @@
-/*  $Revision: 1.57.2.5 $
+/*  $Revision: 1.57.2.7 $
 **
 **  Article-related routines.
 */
@@ -252,6 +252,9 @@ STATIC BOOL ARTinstore(int i)
 	    || token.cancelled )
 	 return FALSE;
     }
+    if (!innconf->nnrpdcheckart) {
+	return TRUE;
+    }
     if (innconf->nnrpdoverstats)
 	gettimeofday(&stv, NULL);
     art = SMretrieve(token, RETR_STAT);
@@ -292,21 +295,27 @@ STATIC int ARTfind(ARTNUM i, BOOL needcheck)
             else
                 return ARTcache - ARTnumbers;
         }
-        else if ((++ARTcache <= top) && (ARTcache->ArtNum <= i)) {
-            /* Next article. */
-            if (ARTcache->ArtNum == i) {
-                if (needcheck) {
-                    return ARTinstore(ARTcache - ARTnumbers)
-                        ? (ARTcache - ARTnumbers) : -1;
+        else if (++ARTcache <= top) {
+            if (ARTcache->ArtNum <= i) {
+                /* Next article. */
+                if (ARTcache->ArtNum == i) {
+                    if (needcheck) {
+                        return ARTinstore(ARTcache - ARTnumbers)
+                            ? (ARTcache - ARTnumbers) : -1;
+                    }
+                    else
+                      return ARTcache - ARTnumbers;
                 }
-                else
-                  return ARTcache - ARTnumbers;
+                bottom = ARTcache;
+            }
+            else if ((--ARTcache)->ArtNum < i ) {
+                /* Missing article. */
+                return -1;
+            }
+            else {
+                ARTcache=NULL;
+                bottom = ARTnumbers;
             }
-            bottom = ARTcache;
-        }
-        else if ( (ARTcache->ArtNum > i) && ((--ARTcache)->ArtNum < i) ) {
-            /* Missing article. */
-            return -1;
         }
         else {
             ARTcache=NULL;
