@@ -1,4 +1,4 @@
-/*  $Revision: 1.20.2.3 $
+/*  $Revision: 1.20.2.5 $
 **
 **  Miscellaneous commands.
 */
@@ -265,6 +265,11 @@ CMDauthinfo(ac, av)
 		PERMspecified = NGgetlist(&PERMlist, accesslist);
 		syslog(L_NOTICE, "%s user %s", ClientHost, User);
 		Reply("%d Ok\r\n", NNTP_AUTH_OK_VAL);
+
+		/* save these values in case you need them later */
+		strcpy(PERMuser, User);
+		strcpy(PERMpass, Password);
+
 		PERMneedauth = FALSE;
 		PERMauthorized = TRUE;
 		return;
@@ -286,9 +291,6 @@ CMDauthinfo(ac, av)
 			fflush(locallog);
 		}
 		Reply("%d Ok\r\n", NNTP_AUTH_OK_VAL);
-		/* save these values in case you need them later */
-		strcpy(PERMuser, User);
-		strcpy(PERMpass, Password);
 		PERMneedauth = FALSE;
 		PERMauthorized = TRUE;
 		return;
@@ -454,6 +456,10 @@ CMDlist(ac, av)
 	    Printf("%s\r\n", p);
 	    continue;
 	}
+	if (p[0] == '.' && p[1] == '\0') {
+	    syslog(L_ERROR, "%s single dot in %s", ClientHost, lp->File);
+	    continue;
+	}
 	/* matching patterns against patterns is not that
 	   good but it's better than nothing ... */
 	if (lp == &INFOdistribpats) {
