@@ -1,4 +1,4 @@
-/*  $Revision: 1.28.2.5 $
+/*  $Revision: 1.28.2.8 $
 **
 **  Check article, send it to the local server.
 */
@@ -522,12 +522,12 @@ ProcessHeaders(linecount)
     if ((p = innconf->complaints) != NULL)
       sprintf (complaintsbuff, "%s",p) ;
     else {
-      if ((p = innconf->fromhost) != NULL) 
-	sprintf (complaintsbuff, "%s@%s",
-                NEWSMASTER, p);
+      if ((p = innconf->fromhost) != NULL && strchr(NEWSMASTER, '@') == NULL)
+	sprintf (complaintsbuff, "%s@%s", NEWSMASTER, p);
+      else
+	sprintf (complaintsbuff, "%s", NEWSMASTER);
     }
-    if (p != NULL)  /* Only show it if we can create it */
-	HDR(_xcomplaintsto) = complaintsbuff ;
+    HDR(_xcomplaintsto) = complaintsbuff ;
 
     /* Clear out some headers that should not be here */
     if (innconf->strippostcc) {
@@ -577,7 +577,7 @@ CheckIncludedText(p, lines)
 	if ((p = strchr(p, '\n')) == NULL)
 	    break;
     }
-    if ((i * 2 > lines) && (lines > 40))
+    if (i * 2 > lines)
 	return "Article not posted -- more included text than new text";
     return NULL;
 }
@@ -952,7 +952,7 @@ ARTpost(article, idbuff)
 		(strlen(article) > innconf->localmaxartsize)) {
 	    (void)sprintf(Error,
 		"Article is bigger then local limit of %ld bytes\n",
-		atoi(p));
+		innconf->localmaxartsize);
 	    if (modgroup)
 		DISPOSE(modgroup);
 	    return Error;
