@@ -36,7 +36,8 @@ my %ctlinnd =
 # init innd timer
 foreach ('article cancel', 'article control', 'article link',
 	 'article write', 'history grep', 'history lookup',
-	 'history sync', 'history write', 'idle', 'site send')
+	 'history sync', 'history write', 'idle', 'site send',
+	 'perl filter')
 {
   $innd_time_min{$_} = $MIN;
   $innd_time_max{$_} = $MAX;
@@ -233,7 +234,7 @@ sub collect
     # running
     return 1 if $left =~ /\S+ running$/o;
     # sleeping
-    if ($left =~ /(\S+):\d+:\proc:\d+ sleeping$/o)
+    if ($left =~ /(\S+):\d+:proc:\d+ sleeping$/o)
     {
       my $server = $1;
       $server =~ tr/A-Z/a-z/ unless ($CASE_SENSITIVE);
@@ -241,7 +242,7 @@ sub collect
       return 1;
     }
     # blocked sleeping
-    if ($left =~ /(\S+):\d+:\proc:\d+ blocked sleeping/o)
+    if ($left =~ /(\S+):\d+:proc:\d+ blocked sleeping/o)
     {
       my $server = $1;
       $server =~ tr/A-Z/a-z/ unless ($CASE_SENSITIVE);
@@ -340,9 +341,7 @@ sub collect
     # time (from the Greco's patch)
     # ME time X idle X(X) artwrite X(X) artlink X(X) hiswrite X(X) hissync
     # X(X) sitesend X(X) artctrl X(X) artcncl X(X) hishave X(X) hisgrep X(X) 
-    # or
-    # ME time X idle X(X) artwrite X(X) artlink X(X) hiswrite X(X) hissync
-    # X(X) sitesend X(X) artctrl X(X) artcncl X(X) hishave X(X)
+    # perl X(X)
     if ($left =~ m/^\S+\s+                         # ME
 	           time\ (\d+)\s+                  # time
 	           idle\ (\d+)\((\d+)\)\s+         # idle
@@ -350,11 +349,12 @@ sub collect
                    artlink\ (\d+)\((\d+)\)\s+      # artlink
                    hiswrite\ (\d+)\((\d+)\)\s+     # hiswrite
                    hissync\ (\d+)\((\d+)\)\s+      # hissync
-                   (?:sitesend\ (\d+)\((\d+)\)\s+  # sitesend
+                   sitesend\ (\d+)\((\d+)\)\s+     # sitesend
                    artctrl\ (\d+)\((\d+)\)\s+      # artctrl
                    artcncl\ (\d+)\((\d+)\)\s+      # artcncl
-                   hishave\ (\d+)\((\d+)\)         # hishave
-                   (?:\s+hisgrep\ (\d+)\((\d+)\))?)?  # hisgrep (optionnal)
+                   hishave\ (\d+)\((\d+)\)\s+      # hishave
+                   hisgrep\ (\d+)\((\d+)\)\s+      # hisgrep
+		   perl\ (\d+)\((\d+)\)\s+	   # perl (optional)
 	           \s*$/ox)
     {
       $innd_time_times += $1;
@@ -421,15 +421,19 @@ sub collect
       $innd_time_max{'history lookup'} = $18 / ($19 || 1)
 	if ($19) && ($innd_time_max{'history lookup'} < $18 / ($19 || 1));
 
-      if ($20 || $21)
-      {
-	$innd_time_time{'history grep'} += $20;
-	$innd_time_num{'history grep'} += $21;
-	$innd_time_min{'history grep'} = $20 / ($21 || 1)
-	  if ($21) && ($innd_time_min{'history grep'} > $20 / ($21 || 1));
-	$innd_time_max{'history grep'} = $20 / ($21 || 1)
-	  if ($21) && ($innd_time_max{'history grep'} < $20 / ($21 || 1));
-      }
+      $innd_time_time{'history grep'} += $20;
+      $innd_time_num{'history grep'} += $21;
+      $innd_time_min{'history grep'} = $20 / ($21 || 1)
+	if ($21) && ($innd_time_min{'history grep'} > $20 / ($21 || 1));
+      $innd_time_max{'history grep'} = $20 / ($21 || 1)
+	if ($21) && ($innd_time_max{'history grep'} < $20 / ($21 || 1));
+
+      $innd_time_time{'perl filter'} += $22;
+      $innd_time_num{'perl filter'} += $23;
+      $innd_time_min{'perl filter'} = $22 / ($23 || 1)
+	if ($23) && ($innd_time_min{'perl filter'} > $22 / ($23 || 1));
+      $innd_time_max{'perl filter'} = $22 / ($23 || 1)
+	if ($23) && ($innd_time_max{'perl filter'} < $22 / ($23 || 1));
       return 1;
     }
     # ME time xx idle xx(xx)     [ bug ? a part of timer ?]
@@ -611,6 +615,8 @@ sub collect
     }
     # bad_newsfeeds no feeding sites
     return 1 if $left =~ /\S+ bad_newsfeeds no feeding sites/o;
+    # CNFS-sm: cycbuff rollover - possibly interesting
+    return 1 if $left =~ /CNFS-sm: cycbuff \S+ rollover to cycle/o;
   }
   ########
   ## innfeed
@@ -1575,6 +1581,8 @@ sub collect
   return 1 if ($prog eq "newsx");
   return 1 if ($prog eq "demmf");
   return 1 if ($prog eq "nnnn");
+  return 1 if ($prog eq "controlchan");
+  return 1 if ($prog eq "cnfsstat");
   return 0;
 }
 
@@ -1763,14 +1771,15 @@ sub adjust
       $hash_time{$date} = $delay;
     }
     my ($h, $t) = $last_date =~ m/ (\d+):(\d\d:\d\d)$/o;
+    my ($h2) = $date =~ m/ (\d+):\d\d:\d\d /o;
     my $date2 = $date;
-    $date2 =~ s/:59:59$/:$t/;
+    $date2 =~ s/$h2:59:59$/$h:$t/;
     $hash{$date2} = $hash{$date};
     undef $hash{"$date"};
     $hash_size{$date2} = $hash_size{$date};
     undef $hash_size{"$date"};
     $t =~ m/(\d\d):(\d\d)/o;
-    $hash_time{$date2} = $hash_time{$date} - 3600 + $1 * 60 + $2;
+    $hash_time{$date2} = $hash_time{$date} - ($h2 == $h) * 3600 + $1 * 60 + $2;
     undef $hash_time{"$date"};
     $inn_flow_labels{$date2} = $h;
     %inn_flow = %hash;
