@@ -1,4 +1,4 @@
-/*  $Id: cnfs.h,v 1.3 1998/03/27 04:08:31 scrappy Exp $
+/*  $Id: cnfs.h,v 1.4 1998/09/06 04:01:20 kondou Exp $
 **
 **  cyclic news file system header
 */
@@ -8,8 +8,8 @@
 
 BOOL cnfs_init(BOOL *selfexpire);
 TOKEN cnfs_store(const ARTHANDLE article, const STORAGECLASS class);
-ARTHANDLE *cnfs_retrieve(const TOKEN token, RETRTYPE amount);
-ARTHANDLE *cnfs_next(const ARTHANDLE *article, RETRTYPE amount);
+ARTHANDLE *cnfs_retrieve(const TOKEN token, const RETRTYPE amount);
+ARTHANDLE *cnfs_next(const ARTHANDLE *article, const RETRTYPE amount);
 void cnfs_freearticle(ARTHANDLE *article);
 BOOL cnfs_cancel(TOKEN token);
 void cnfs_shutdown(void);
