@@ -1,4 +1,4 @@
-/*  $Id: interface.c,v 1.35.2.1 1998/11/07 03:19:55 kondou Exp $
+/*  $Id: interface.c,v 1.35.2.3 1999/06/26 00:35:07 kondou Exp $
 **
 **  Storage Manager interface
 */
@@ -364,6 +364,15 @@ static BOOL SMreadconfig(void) {
 	    DISPOSE(patterns);
 	    patterns = NULL;
 
+	    if (i != sub->numpatterns) {
+	      /* Spurious ',' */
+	      SMseterror(SMERR_CONFIG, "extra ',' in pattern");
+	      syslog(L_ERROR, "SM extra ',' in pattern");
+	      DISPOSE(options);
+	      DISPOSE(sub);
+	      return FALSE;
+	    }
+
 	    if (prev)
 		prev->next = sub;
 	    prev = sub;
@@ -511,6 +520,7 @@ static BOOL MatchGroups(const char *g, int num, char **patterns) {
 		    DISPOSE(groups);
 		    return FALSE;
 		}
+		break;
 	    default:
 		if (wildmat(group, patterns[i]))
 		    wanted = TRUE;
