@@ -1,4 +1,4 @@
-/*  $Id: overview.c,v 1.32 1998/06/04 23:37:20 kondou Exp $
+/*  $Id: overview.c,v 1.32.4.1 1999/05/18 21:45:30 kondou Exp $
 **
 **  unified overview processing
 */
@@ -376,8 +376,15 @@ STATIC OVERCONFIG OVERreadconfig(BOOL New)
 	    newconfig->numpatterns = i;
 	    newconfig->patterns = NEW(char *, i);
 	    /* Store the patterns */
-	    for (i = 0, p = strtok(patterns, ","); p != NULL; i++, p = strtok(NULL, ","))
+	    for (i = 0, p = strtok(patterns, ","); p != NULL; i++, p = strtok(NULL, ",")) {
+		if (*p == '\0') {
+		    syslog(L_ERROR, "OVER null pattern, line %d", line);
+		    DISPOSE(newconfig);
+		    (void)Fclose(f);
+		    return OVER_ERROR;
+		}
 	        newconfig->patterns[i] = COPY(p);
+	    }
 	    if (prev)
 		prev->next = newconfig;
 	    else
