@@ -1,4 +1,4 @@
-/*  $Id: timehash.c,v 1.24 1998/06/18 05:32:24 kondou Exp $
+/*  $Id: timehash.c,v 1.28 1998/10/13 13:52:24 coneill Exp $
 **
 **  timehash based storing method
 */
@@ -7,6 +7,7 @@
 #include <errno.h>
 #include <unistd.h>
 #include <time.h>
+#include <sys/types.h>
 #include <netinet/in.h>
 #include <fcntl.h>
 #include <sys/stat.h>
@@ -103,7 +104,7 @@ BOOL timehash_init(BOOL *selfexpire) {
     return TRUE;
 }
 
-TOKEN timehash_store(const ARTHANDLE article, STORAGECLASS class) {
+TOKEN timehash_store(const ARTHANDLE article, const STORAGECLASS class) {
     char                *path;
     char                *p;
     time_t              now;
@@ -261,7 +262,7 @@ static ARTHANDLE *OpenArticle(const char *path, RETRTYPE amount) {
     return NULL;
 }
 
-ARTHANDLE *timehash_retrieve(const TOKEN token, RETRTYPE amount) {
+ARTHANDLE *timehash_retrieve(const TOKEN token, const RETRTYPE amount) {
     int                 time;
     int                 seqnum;
     char                *path;
@@ -293,7 +294,7 @@ void timehash_freearticle(ARTHANDLE *article) {
     if (article->private) {
 	private = (PRIV_TIMEHASH *)article->private;
 	if (innconf->articlemmap) {
-#if defined(MADV_DONTNEED) && !defined(_nec_ews)
+#if defined(MADV_DONTNEED) && defined(HAVE_MADVISE)
 	    madvise(private->base, private->len, MADV_DONTNEED);
 #endif
 	    munmap(private->base, private->len);
@@ -337,24 +338,24 @@ static struct dirent *FindDir(DIR *dir, FINDTYPE type) {
         if (type == FIND_TOPDIR)
 	    if ((strlen(de->d_name) == 7) &&
 		(strncmp(de->d_name, "time-", 5) == 0) &&
-		isxdigit(de->d_name[5]) &&
-		isxdigit(de->d_name[6]))
+		isxdigit((int)de->d_name[5]) &&
+		isxdigit((int)de->d_name[6]))
 	        return de;
 
 	if (type == FIND_DIR)
-	    if ((strlen(de->d_name) == 2) && isxdigit(de->d_name[0]) && isxdigit(de->d_name[1]))
+	    if ((strlen(de->d_name) == 2) && isxdigit((int)de->d_name[0]) && isxdigit((int)de->d_name[1]))
 		return de;
 
 	if (type == FIND_ART)
 	    if ((strlen(de->d_name) == 9) &&
-		isxdigit(de->d_name[0]) &&
-		isxdigit(de->d_name[1]) &&
-		isxdigit(de->d_name[2]) &&
-		isxdigit(de->d_name[3]) &&
-		isxdigit(de->d_name[5]) &&
-		isxdigit(de->d_name[6]) &&
-		isxdigit(de->d_name[7]) &&
-		isxdigit(de->d_name[8]) &&
+		isxdigit((int)de->d_name[0]) &&
+		isxdigit((int)de->d_name[1]) &&
+		isxdigit((int)de->d_name[2]) &&
+		isxdigit((int)de->d_name[3]) &&
+		isxdigit((int)de->d_name[5]) &&
+		isxdigit((int)de->d_name[6]) &&
+		isxdigit((int)de->d_name[7]) &&
+		isxdigit((int)de->d_name[8]) &&
 		(de->d_name[4] == '-'))
 		return de;
 	}
@@ -362,10 +363,10 @@ static struct dirent *FindDir(DIR *dir, FINDTYPE type) {
     return NULL;
 }
 
-ARTHANDLE *timehash_next(const ARTHANDLE *article, RETRTYPE amount) {
+ARTHANDLE *timehash_next(const ARTHANDLE *article, const RETRTYPE amount) {
     PRIV_TIMEHASH       priv;
     PRIV_TIMEHASH       *newpriv;
-    char                *path, *p;
+    char                *path;
     struct dirent       *de;
     ARTHANDLE           *art;
     int                 seqnum;
@@ -384,7 +385,7 @@ ARTHANDLE *timehash_next(const ARTHANDLE *article, RETRTYPE amount) {
 	DISPOSE(article->private);
 	DISPOSE(article);
 	if (innconf->articlemmap) {
-#if defined(MADV_DONTNEED) && !defined(_nec_ews)
+#if defined(MADV_DONTNEED) && defined(HAVE_MADVISE)
 	    madvise(priv.base, priv.len, MADV_DONTNEED);
 #endif
 	    munmap(priv.base, priv.len);
